%% cameraCalibrator app

%%

close all
clear

% Define images to process
imageFileNames = {'2012_0524_1.JPG',...
    '2012_0524_2.JPG',...
    '2012_0524_3.JPG',...
    };
%%

fprintf('Detect checkerboards in images\n');
% Detect checkerboards in images
[imagePoints, boardSize, imagesUsed] = detectCheckerboardPoints(imageFileNames);
imageFileNames = imageFileNames(imagesUsed);


%%

% Read the first image to obtain image size
originalImage = imread(imageFileNames{1});
[mrows, ncols, ~] = size(originalImage);

% Generate world coordinates of the corners of the squares
squareSize = 3;  % in units of 'inches'
worldPoints = generateCheckerboardPoints(boardSize, squareSize);

%%

% Calibrate the camera
[cameraParams, imagesUsed, estimationErrors] = estimateCameraParameters(imagePoints, worldPoints, ...
    'EstimateSkew', false, 'EstimateTangentialDistortion', false, ...
    'NumRadialDistortionCoefficients', 2, 'WorldUnits', 'inches', ...
    'InitialIntrinsicMatrix', [], 'InitialRadialDistortion', [], ...
    'ImageSize', [mrows, ncols]);

%%

% Display parameter estimation errors
displayErrors(estimationErrors, cameraParams);

%%

% View reprojection errors
figure; showReprojectionErrors(cameraParams);

%%

% Visualize pattern locations
figure; showExtrinsics(cameraParams, 'CameraCentric');


%%

% For example, you can use the calibration data to remove effects of lens distortion.
% undistortedImage = undistortImage(originalImage, cameraParams);

% See additional examples of how to use the calibration data.  At the prompt type:
% showdemo('MeasuringPlanarObjectsExample')
% showdemo('StructureFromMotionExample')
